morenines: A simple content change detector
===========================================

``morenines`` hashes your files and, later, can tell you if they have changed.

Basic usage looks like this::

    $ cd ~/photos
    $ mn create
    $ mn verify

You can find more details on teh `project page`_.

.. _project page: https://github.com/mcgid/morenines
